{% extends "layout.html" %}
{% block title %}- Folder List{% endblock %}
{% block add_button %}
    <a class="navbar-item has-tooltip-bottom has-tooltip-hidden-desktop" data-tooltip="Back"
       href="{{ url_for('admin') }}">
        <i class="fa fa-arrow-left"></i><i>&nbsp;</i>
        <span class="is-hidden-mobile">Back</span>
    </a>
    <a class="navbar-item has-tooltip-bottom has-tooltip-hidden-desktop" data-tooltip="Add folder"
       href="{{ url_for('folder_edit') }}">
        <i class="fa fa-plus"></i><i>&nbsp;</i>
        <span class="is-hidden-mobile">Add folder</span>
    </a>
{% endblock %}
{% block body %}
    <table class="table is-bordered is-striped is-narrow is-fullwidth is-hoverable is-size-7">
        <thead>
        <tr>
            <th>Name</th>
            <th>Path</th>
            <th>Tools</th>
        </tr>
        </thead>
        <tbody>

        {% for folder in folders %}
            <tr>
                <td>{{ folder.name }}</td>
                <td>{{ folder.path }}</td>
                <td>
                    <a href="{{ url_for('folder_edit', folder_id=folder.id) }}">
                        <i class="fa fa-pencil"></i>
                    </a>
                    <i>&nbsp;</i>
                    <form method="post">
                        {{ action_form.id(value=folder.id) }}
                        <button class="fa fa-trash fa-button"
                                onclick="return confirm('Are you sure you want to delete this item ?')">
                        </button>
                    </form>
                </td>
            </tr>
        {% endfor %}

        </tbody>
    </table>
{% endblock %}
